@@ -21,7 +21,7 @@ impl core::fmt::Debug for BoundingBox {
 #[allow(unused)]
 impl BoundingBox {
     /// A [`BoundingBox`] that only contains [`Vec3::ZERO`].
-    pub const ZERO: BoundingBox = BoundingBox {
+    pub const ZERO: Self = Self {
         min: Vec3::ZERO,
         max: Vec3::ZERO,
     };
