@@ -1,4 +1,4 @@
-use glam::{Mat4, Quat, Vec3, Vec3A};
+use glam::{Affine3A, Mat4, Quat, Vec3, Vec3A};
 
 /// An isometric transform represented by translation * rotation.
 ///
@@ -151,6 +151,7 @@ impl IsoTransform {
 
     /// Get the transform that undoes this transform so that `t.inverse() * t == IDENTITY`.
     #[inline(always)]
+    #[must_use]
     pub fn inverse(&self) -> Self {
         let inv_rotation = self.rotation.inverse();
         Self {
@@ -162,6 +163,7 @@ impl IsoTransform {
     /// Returns self normalized.
     /// You generally don't need to call this unless you've multiplied A LOT of `IsoTransforms`.
     #[inline(always)]
+    #[must_use]
     pub fn normalize(&self) -> Self {
         Self {
             rotation: self.rotation.normalize(),
@@ -182,6 +184,7 @@ impl IsoTransform {
     }
 }
 
+/// iso * iso -> iso
 impl core::ops::Mul for &IsoTransform {
     type Output = IsoTransform;
 
@@ -214,6 +217,26 @@ impl core::ops::Mul for IsoTransform {
     }
 }
 
+/// iso * affine3a -> affine3a
+impl core::ops::Mul<Affine3A> for IsoTransform {
+    type Output = Affine3A;
+
+    #[inline(always)]
+    fn mul(self, rhs: Affine3A) -> Affine3A {
+        Affine3A::from(self).mul(rhs)
+    }
+}
+
+/// affine3a * iso -> affine3a
+impl core::ops::Mul<IsoTransform> for Affine3A {
+    type Output = Self;
+
+    #[inline(always)]
+    fn mul(self, rhs: IsoTransform) -> Self {
+        self.mul(Self::from(rhs))
+    }
+}
+
 /// mat4 * iso -> mat4
 impl core::ops::Mul<Mat4> for IsoTransform {
     type Output = Mat4;
@@ -237,7 +260,7 @@ impl core::ops::Mul<IsoTransform> for Mat4 {
 impl From<IsoTransform> for crate::Affine3A {
     #[inline(always)]
     fn from(iso: IsoTransform) -> Self {
-        crate::Affine3A::from_rotation_translation(iso.rotation(), iso.translation())
+        Self::from_rotation_translation(iso.rotation(), iso.translation())
     }
 }
 
@@ -363,10 +386,7 @@ mod test {
 
     fn test_single_transform(t: IsoTransform) {
         #[cfg(feature = "std")]
-        eprintln!(
-            "-------------------------------------------\nTesting {:?}",
-            t
-        );
+        eprintln!("-------------------------------------------\nTesting {t:?}",);
 
         assert_approx_eq_transform!(t, IsoTransform::from_mat4(&t.to_mat4()).unwrap());
         assert_approx_eq_transform!(t, t.inverse().inverse());
@@ -400,10 +420,7 @@ mod test {
 
     fn test_transform_mul(a: IsoTransform, b: IsoTransform) {
         #[cfg(feature = "std")]
-        eprintln!(
-            "-------------------------------------------\nTesting {:?} x {:?}",
-            a, b
-        );
+        eprintln!("-------------------------------------------\nTesting {a:?} x {b:?}",);
 
         assert_approx_eq_transform!(
             a * b,
