@@ -1,5 +1,4 @@
-use super::prelude::*;
-use super::{uvec4, vec4, UVec4, Vec4};
+use super::{prelude::*, uvec4, vec4, UVec4, Vec4};
 
 #[cfg(target_arch = "spirv")]
 use num_traits::Float;
@@ -9,23 +8,29 @@ use num_traits::Float;
 /// Adds additional functionality to [`Vec4`] that [`glam`] doesn't have.
 pub trait Vec4Ext {
     /// For element `i` of `self`, return `v[i].trunc()`
+    #[must_use]
     fn trunc(self) -> Self;
 
     /// For element `i` of the return value, returns 0.0 if `value[i] < self[i]` and 1.0 otherwise.
     ///
     /// Similar to glsl's step(edge, x), which translates into edge.step(x)
+    #[must_use]
     fn step(self, value: Self) -> Self;
 
     /// Selects between `true` and `false` based on the result of `value[i] < self[i]`
+    #[must_use]
     fn step_select(self, value: Self, tru: Self, fals: Self) -> Self;
 
     /// Return only the fractional parts of each component.
+    #[must_use]
     fn fract(self) -> Self;
 
     /// Return the square root of each component.
+    #[must_use]
     fn sqrt(self) -> Self;
 
     /// Raw transmute each component to u32.
+    #[must_use]
     fn to_bits(self) -> UVec4;
 }
 
@@ -40,7 +45,7 @@ impl Vec4Ext for Vec4 {
         )
     }
 
-    fn step(self, value: Vec4) -> Self {
+    fn step(self, value: Self) -> Self {
         vec4(
             self.x.step(value.x),
             self.y.step(value.y),
